Struct embedded_flight::copter::control::Controller
source · [−]pub struct Controller {
pub altitude: AltitudeController,
pub attitude: AttitudeController,
pub body_rate: BodyRateController,
pub lateral_position: LateralPositionController,
pub yaw: YawController,
}Fields
altitude: AltitudeControllerattitude: AttitudeControllerbody_rate: BodyRateControllerlateral_position: LateralPositionControlleryaw: YawControllerImplementations
sourceimpl Controller
impl Controller
sourcepub fn position_control(
&self,
local_position_cmd: Vector3<f32>,
local_velocity_cmd: Vector3<f32>,
local_position: Vector3<f32>,
local_velocity: Vector3<f32>,
attitude: Vector3<f32>,
gyro: Vector3<f32>,
moment_of_inertia: Vector3<f32>
) -> (Vector3<f32>, f32)
pub fn position_control(
&self,
local_position_cmd: Vector3<f32>,
local_velocity_cmd: Vector3<f32>,
local_position: Vector3<f32>,
local_velocity: Vector3<f32>,
attitude: Vector3<f32>,
gyro: Vector3<f32>,
moment_of_inertia: Vector3<f32>
) -> (Vector3<f32>, f32)
Calculate the desired roll, pitch and yaw torque (in Nm) with the thrust acceleration (in m/s^2).
sourcepub fn position_control_with_feed_forward(
&self,
local_position_cmd: Vector3<f32>,
local_velocity_cmd: Vector3<f32>,
local_position: Vector3<f32>,
local_velocity: Vector3<f32>,
attitude: Vector3<f32>,
gyro: Vector3<f32>,
moment_of_inertia: Vector3<f32>,
acceleration_ff: Vector2<f32>
) -> (Vector3<f32>, f32)
pub fn position_control_with_feed_forward(
&self,
local_position_cmd: Vector3<f32>,
local_velocity_cmd: Vector3<f32>,
local_position: Vector3<f32>,
local_velocity: Vector3<f32>,
attitude: Vector3<f32>,
gyro: Vector3<f32>,
moment_of_inertia: Vector3<f32>,
acceleration_ff: Vector2<f32>
) -> (Vector3<f32>, f32)
Calculate the desired roll, pitch and yaw torque (in Nm) with the thrust acceleration (in m/s^2).