Struct embedded_flight::scheduler::Scheduler
source · [−]pub struct Scheduler<'a, C, T, E = Error> {
pub tasks: &'a mut [Task<T, E>],
pub clock: C,
pub tick: u16,
pub max_task_slowdown: u8,
pub loop_rate_hz: i16,
pub task_not_achieved: u32,
pub task_all_achieved: u32,
pub loop_timer_start_us: u32,
pub last_loop_time_s: f32,
pub extra_loop_us: u32,
/* private fields */
}Expand description
Task scheduler for flight controllers
Fields
tasks: &'a mut [Task<T, E>]The tasks to run in order of highest to lowest priority.
clock: CThe clock used for timing.
tick: u16The current tick, incremented each run.
max_task_slowdown: u8The maximum amount of ticks a task can miss before slowing down the scheduler.
loop_rate_hz: i16The desired loop rate to run (in hz).
task_not_achieved: u32The amount of ticks with tasks that exceed the max_task_slowdown.
task_all_achieved: u32The amount of ticks with tasks that remain in the max_task_slowdown.
loop_timer_start_us: u32The start time of the run loop (in microseconds).
last_loop_time_s: f32The start time of the run loop (in seconds).
extra_loop_us: u32Extra time to spend in the loop to catch up on tasks not achieved (in microseconds).
Implementations
sourceimpl<'a, C, T, E> Scheduler<'a, C, T, E> where
C: Clock,
C::T: ToPrimitive,
E: From<Error>,
impl<'a, C, T, E> Scheduler<'a, C, T, E> where
C: Clock,
C::T: ToPrimitive,
E: From<Error>,